@@ -24,9 +24,9 @@
 #include "standardmailactionmanager.h"
 
 #include "akonadi_mime_debug.h"
-#include "emptytrashcommand_p.h"
-#include "markascommand_p.h"
-#include "movetotrashcommand_p.h"
+#include "emptytrashcommand.h"
+#include "markascommand.h"
+#include "movetotrashcommand.h"
 #include "specialmailcollections.h"
 #include "removeduplicatesjob.h"
 #include "util_p.h"
@@ -55,7 +55,7 @@
 
 using namespace Akonadi;
 
-class StandardMailActionManager::Private
+class Q_DECL_HIDDEN StandardMailActionManager::Private
 {
 public:
     Private(KActionCollection *actionCollection, QWidget *parentWidget, StandardMailActionManager *parent)
@@ -67,8 +67,8 @@ public:
     {
         mGenericManager = new StandardActionManager(actionCollection, parentWidget);
 
-        mParent->connect(mGenericManager, SIGNAL(actionStateUpdated()),
-                         mParent, SIGNAL(actionStateUpdated()));
+        mParent->connect(mGenericManager, &StandardActionManager::actionStateUpdated,
+                         mParent, &StandardMailActionManager::actionStateUpdated);
 
         mGenericManager->setMimeTypeFilter(QStringList() << KMime::Message::mimeType());
         mGenericManager->setCapabilityFilter(QStringList() << QStringLiteral("Resource"));
